@@ -3,8 +3,7 @@ from os.path import dirname, abspath, split
 import sys
 
 sys.path = [split(abspath(dirname(__file__)))[0]] + sys.path
-
-from pycorrfit.gui import main
+from pycorrfit.gui import main  # noqa: E402
 
 
 if __name__ == "__main__":
