@@ -1,11 +1,12 @@
 """CSV files"""
 import csv
-import os
+import pathlib
+import warnings
 
 import numpy as np
 
 
-def openCSV(dirname, filename):
+def openCSV(path, filename=None):
     """
     Read relevant data from a file looking like this:
         [...]
@@ -64,24 +65,27 @@ def openCSV(dirname, filename):
     3. A list with one element, indicating, that we are opening only
        one correlation curve.
     """
+    path = pathlib.Path(path)
+    if filename is not None:
+        warnings.warn("Using `filename` is deprecated.", DeprecationWarning)
+        path = path / filename
+    filename = path.name
     # Check if the file is correlation data
-    csvfile = open(os.path.join(dirname, filename), 'r', encoding='utf-8')
-    firstline = csvfile.readline()
-    if firstline.lower().count("this is not correlation data") > 0:
-        csvfile.close()
-        return None
-    csvfile.close()
+    with path.open("r", encoding='utf-8') as fd:
+        firstline = fd.readline()
+        if firstline.lower().count("this is not correlation data") > 0:
+            return None
 
     # Define what will happen to the file
-    timefactor = 1000 # because we want ms instead of s
-    csvfile = open(os.path.join(dirname, filename), 'r', encoding='utf-8')
+    timefactor = 1000  # because we want ms instead of s
+    csvfile = path.open('r', encoding='utf-8')
     readdata = csv.reader(csvfile, delimiter=',')
     data = list()
     weights = list()
     weightname = "external"
     trace = None
     traceA = None
-    DataType="AC" # May be changed
+    DataType = "AC"  # May be changed
     numtraces = 0
     prev_row = None
     for row in readdata:
@@ -95,15 +99,15 @@ def openCSV(dirname, filename):
             corrtype = str(row[0])[12:].strip().strip(":").strip()
             if corrtype[:17].lower() == "cross-correlation":
                 # We will later try to import a second trace
-                DataType="CC"
+                DataType = "CC"
                 DataType += corrtype[17:].strip()
             elif corrtype[0:15].lower() == "autocorrelation":
-                DataType="AC"
+                DataType = "AC"
                 DataType += corrtype[15:].strip()
         elif str(row[0])[0:13].upper() == '# BEGIN TRACE':
             # Correlation is over. We have a trace
             corr = np.array(data)
-            data=list()
+            data = list()
             numtraces = 1
         elif str(row[0])[0:20].upper() == '# BEGIN SECOND TRACE':
             # First trace is over. We have a second trace
@@ -115,8 +119,8 @@ def openCSV(dirname, filename):
             # Read the 1st section
             # On Windows we had problems importing nan values that
             # had some white-spaces around them. Therefore: strip()
-            ## As of version 0.7.8 we are supporting white space
-            ## separated values as well
+            # As of version 0.7.8 we are supporting white space
+            # separated values as well
             if len(row) == 1:
                 row = row[0].split()
             data.append((np.float(row[0].strip())*timefactor,
@@ -126,7 +130,9 @@ def openCSV(dirname, filename):
                 weights.append(np.float(row[4].strip()))
                 if weightname == "external":
                     try:
-                        weightname = "ext. "+prev_row[0].split("Weights")[1].split("[")[1].split("]")[0]
+                        weightname = "ext. " + \
+                            prev_row[0].split("Weights")[1].split(
+                                "[")[1].split("]")[0]
                     except:
                         pass
         prev_row = row
@@ -137,7 +143,7 @@ def openCSV(dirname, filename):
     elif numtraces >= 1:
         trace = rest
     del data
-    ## Remove any NaN numbers from thearray
+    # Remove any NaN numbers from thearray
     # Explanation:
     # np.isnan(data)
     #  finds the position of NaNs in the array (True positions); 2D array, bool
@@ -150,7 +156,7 @@ def openCSV(dirname, filename):
     # Also check for infinities.
     corr = corr[~np.isinf(corr).any(1)]
     csvfile.close()
-    Traces=list()
+    Traces = list()
     # Set correct trace data for import
     if numtraces == 1 and DataType[:2] == "AC":
         Traces.append(trace)
@@ -167,6 +173,6 @@ def openCSV(dirname, filename):
     dictionary["Type"] = [DataType]
     dictionary["Filename"] = [filename]
     if len(weights) != 0:
-        dictionary["Weight"] = [ np.array(weights)]
+        dictionary["Weight"] = [np.array(weights)]
         dictionary["Weight Name"] = [weightname]
     return dictionary
